.. AnyBlok / Pyramid documentation master file, created by
   sphinx-quickstart on Wed Feb  4 16:19:23 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

AnyBlok / Pyramid's documentation
=================================

Contents:

.. toctree::
   :maxdepth: 2

   FRONT.rst
   MEMENTO.rst
   CODE.rst
   BLOKS.rst
   UNITTEST.rst
   CHANGES.rst
   LICENSE.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

